@@ -413,7 +413,7 @@ void QalculateExpressionEdit::keyPressEvent(TQKeyEvent *e) {
 	switch(e->key()) {
 		case Key_Period: {
 			if(e->state() == Keypad) {
-				insert(CALCULATOR->getDecimalPoint());	
+				insert(CALCULATOR->getDecimalPoint().c_str());	
 				e->accept();
 				return;
 			}
@@ -421,7 +421,7 @@ void QalculateExpressionEdit::keyPressEvent(TQKeyEvent *e) {
 		}
 		case Key_Comma: {
 			if(e->state() == Keypad) {
-				insert(CALCULATOR->getDecimalPoint());
+				insert(CALCULATOR->getDecimalPoint().c_str());
 				e->accept();
 				return;
 			}
